# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from ProvisioningPortal.api_client import ApiClient


class CloudApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cloud_connection_test_status(self, job_id, **kwargs):  # noqa: E501
        """cloud_connection_test_status  # noqa: E501

        Gets the cloud connectivity test job status and results.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cloud_connection_test_status(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: Job ID returned from /clouds/test_connection REST API. (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cloud_connection_test_status_with_http_info(job_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cloud_connection_test_status_with_http_info(job_id, **kwargs)  # noqa: E501
            return data

    def cloud_connection_test_status_with_http_info(self, job_id, **kwargs):  # noqa: E501
        """cloud_connection_test_status  # noqa: E501

        Gets the cloud connectivity test job status and results.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cloud_connection_test_status_with_http_info(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: Job ID returned from /clouds/test_connection REST API. (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cloud_connection_test_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'job_id' is set
        if self.api_client.client_side_validation and ('job_id' not in params or
                                                       params['job_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `job_id` when calling `cloud_connection_test_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'job_id' in params:
            query_params.append(('job_id', params['job_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/connection_test_status.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cloud_test_connection(self, cloud_test_connection, **kwargs):  # noqa: E501
        """cloud_test_connection  # noqa: E501

        Test connectivity to Auth, Nova and Keystone URLs of the cloud. Runs a background job and returns the job id. Job status and results should be tracked with /clouds/connection_test_status REST API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cloud_test_connection(cloud_test_connection, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CloudTestConnection cloud_test_connection: (required)
        :return: InlineResponse2003
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cloud_test_connection_with_http_info(cloud_test_connection, **kwargs)  # noqa: E501
        else:
            (data) = self.cloud_test_connection_with_http_info(cloud_test_connection, **kwargs)  # noqa: E501
            return data

    def cloud_test_connection_with_http_info(self, cloud_test_connection, **kwargs):  # noqa: E501
        """cloud_test_connection  # noqa: E501

        Test connectivity to Auth, Nova and Keystone URLs of the cloud. Runs a background job and returns the job id. Job status and results should be tracked with /clouds/connection_test_status REST API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cloud_test_connection_with_http_info(cloud_test_connection, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CloudTestConnection cloud_test_connection: (required)
        :return: InlineResponse2003
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_test_connection']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cloud_test_connection" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_test_connection' is set
        if self.api_client.client_side_validation and ('cloud_test_connection' not in params or
                                                       params['cloud_test_connection'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_test_connection` when calling `cloud_test_connection`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'cloud_test_connection' in params:
            body_params = params['cloud_test_connection']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/test_connection.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2003',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_cloud(self, create_cloud, **kwargs):  # noqa: E501
        """create_cloud  # noqa: E501

        Create a cloud  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_cloud(create_cloud, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCloud create_cloud: (required)
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_cloud_with_http_info(create_cloud, **kwargs)  # noqa: E501
        else:
            (data) = self.create_cloud_with_http_info(create_cloud, **kwargs)  # noqa: E501
            return data

    def create_cloud_with_http_info(self, create_cloud, **kwargs):  # noqa: E501
        """create_cloud  # noqa: E501

        Create a cloud  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_cloud_with_http_info(create_cloud, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCloud create_cloud: (required)
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_cloud']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_cloud" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_cloud' is set
        if self.api_client.client_side_validation and ('create_cloud' not in params or
                                                       params['create_cloud'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_cloud` when calling `create_cloud`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_cloud' in params:
            body_params = params['create_cloud']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2002',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_cloud(self, id, **kwargs):  # noqa: E501
        """delete_cloud  # noqa: E501

        Delete a cloud  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_cloud(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse2006
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_cloud_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_cloud_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_cloud_with_http_info(self, id, **kwargs):  # noqa: E501
        """delete_cloud  # noqa: E501

        Delete a cloud  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_cloud_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse2006
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_cloud" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_cloud`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{id}.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2006',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_clouds(self, **kwargs):  # noqa: E501
        """get_all_clouds  # noqa: E501

        Get the list of available Clouds and their configuration options.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_clouds(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_clouds_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_clouds_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_clouds_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_clouds  # noqa: E501

        Get the list of available Clouds and their configuration options.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_clouds_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_clouds" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2001',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_cloud(self, id, **kwargs):  # noqa: E501
        """get_cloud  # noqa: E501

        Get the configuration information for a single Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cloud(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse2005
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_cloud_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_cloud_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_cloud_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_cloud  # noqa: E501

        Get the configuration information for a single Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cloud_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse2005
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cloud" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_cloud`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2005',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_cloud(self, id, update_cloud, **kwargs):  # noqa: E501
        """update_cloud  # noqa: E501

        Update a cloud  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_cloud(id, update_cloud, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UpdateCloud update_cloud: (required)
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_cloud_with_http_info(id, update_cloud, **kwargs)  # noqa: E501
        else:
            (data) = self.update_cloud_with_http_info(id, update_cloud, **kwargs)  # noqa: E501
            return data

    def update_cloud_with_http_info(self, id, update_cloud, **kwargs):  # noqa: E501
        """update_cloud  # noqa: E501

        Update a cloud  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_cloud_with_http_info(id, update_cloud, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UpdateCloud update_cloud: (required)
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'update_cloud']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_cloud" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_cloud`")  # noqa: E501
        # verify the required parameter 'update_cloud' is set
        if self.api_client.client_side_validation and ('update_cloud' not in params or
                                                       params['update_cloud'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `update_cloud` when calling `update_cloud`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_cloud' in params:
            body_params = params['update_cloud']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{id}.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2002',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class RemoteVpsa(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'remote_name': 'str',
        'remote_display_name': 'str',
        'provider': 'str',
        'software_version': 'str',
        'uuid': 'str',
        'ip': 'str',
        'public': 'str',
        'report_failure': 'str',
        'vni': 'str',
        'status': 'str',
        'limited_higher_rate_in_kbs': 'int',
        'features': 'RemoteVpsaFeatures'
    }

    attribute_map = {
        'name': 'name',
        'remote_name': 'remote_name',
        'remote_display_name': 'remote_display_name',
        'provider': 'provider',
        'software_version': 'software_version',
        'uuid': 'uuid',
        'ip': 'ip',
        'public': 'public',
        'report_failure': 'report_failure',
        'vni': 'vni',
        'status': 'status',
        'limited_higher_rate_in_kbs': 'limited_higher_rate_in_KBS',
        'features': 'features'
    }

    def __init__(self, name=None, remote_name=None, remote_display_name=None, provider=None, software_version=None, uuid=None, ip=None, public=None, report_failure=None, vni=None, status=None, limited_higher_rate_in_kbs=None, features=None, _configuration=None):  # noqa: E501
        """RemoteVpsa - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._remote_name = None
        self._remote_display_name = None
        self._provider = None
        self._software_version = None
        self._uuid = None
        self._ip = None
        self._public = None
        self._report_failure = None
        self._vni = None
        self._status = None
        self._limited_higher_rate_in_kbs = None
        self._features = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if remote_name is not None:
            self.remote_name = remote_name
        if remote_display_name is not None:
            self.remote_display_name = remote_display_name
        if provider is not None:
            self.provider = provider
        if software_version is not None:
            self.software_version = software_version
        if uuid is not None:
            self.uuid = uuid
        if ip is not None:
            self.ip = ip
        if public is not None:
            self.public = public
        if report_failure is not None:
            self.report_failure = report_failure
        if vni is not None:
            self.vni = vni
        if status is not None:
            self.status = status
        if limited_higher_rate_in_kbs is not None:
            self.limited_higher_rate_in_kbs = limited_higher_rate_in_kbs
        if features is not None:
            self.features = features

    @property
    def name(self):
        """Gets the name of this RemoteVpsa.  # noqa: E501


        :return: The name of this RemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RemoteVpsa.


        :param name: The name of this RemoteVpsa.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def remote_name(self):
        """Gets the remote_name of this RemoteVpsa.  # noqa: E501


        :return: The remote_name of this RemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._remote_name

    @remote_name.setter
    def remote_name(self, remote_name):
        """Sets the remote_name of this RemoteVpsa.


        :param remote_name: The remote_name of this RemoteVpsa.  # noqa: E501
        :type: str
        """

        self._remote_name = remote_name

    @property
    def remote_display_name(self):
        """Gets the remote_display_name of this RemoteVpsa.  # noqa: E501


        :return: The remote_display_name of this RemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._remote_display_name

    @remote_display_name.setter
    def remote_display_name(self, remote_display_name):
        """Sets the remote_display_name of this RemoteVpsa.


        :param remote_display_name: The remote_display_name of this RemoteVpsa.  # noqa: E501
        :type: str
        """

        self._remote_display_name = remote_display_name

    @property
    def provider(self):
        """Gets the provider of this RemoteVpsa.  # noqa: E501


        :return: The provider of this RemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this RemoteVpsa.


        :param provider: The provider of this RemoteVpsa.  # noqa: E501
        :type: str
        """

        self._provider = provider

    @property
    def software_version(self):
        """Gets the software_version of this RemoteVpsa.  # noqa: E501


        :return: The software_version of this RemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._software_version

    @software_version.setter
    def software_version(self, software_version):
        """Sets the software_version of this RemoteVpsa.


        :param software_version: The software_version of this RemoteVpsa.  # noqa: E501
        :type: str
        """

        self._software_version = software_version

    @property
    def uuid(self):
        """Gets the uuid of this RemoteVpsa.  # noqa: E501


        :return: The uuid of this RemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this RemoteVpsa.


        :param uuid: The uuid of this RemoteVpsa.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def ip(self):
        """Gets the ip of this RemoteVpsa.  # noqa: E501


        :return: The ip of this RemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this RemoteVpsa.


        :param ip: The ip of this RemoteVpsa.  # noqa: E501
        :type: str
        """

        self._ip = ip

    @property
    def public(self):
        """Gets the public of this RemoteVpsa.  # noqa: E501


        :return: The public of this RemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this RemoteVpsa.


        :param public: The public of this RemoteVpsa.  # noqa: E501
        :type: str
        """

        self._public = public

    @property
    def report_failure(self):
        """Gets the report_failure of this RemoteVpsa.  # noqa: E501


        :return: The report_failure of this RemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._report_failure

    @report_failure.setter
    def report_failure(self, report_failure):
        """Sets the report_failure of this RemoteVpsa.


        :param report_failure: The report_failure of this RemoteVpsa.  # noqa: E501
        :type: str
        """

        self._report_failure = report_failure

    @property
    def vni(self):
        """Gets the vni of this RemoteVpsa.  # noqa: E501


        :return: The vni of this RemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._vni

    @vni.setter
    def vni(self, vni):
        """Sets the vni of this RemoteVpsa.


        :param vni: The vni of this RemoteVpsa.  # noqa: E501
        :type: str
        """

        self._vni = vni

    @property
    def status(self):
        """Gets the status of this RemoteVpsa.  # noqa: E501


        :return: The status of this RemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this RemoteVpsa.


        :param status: The status of this RemoteVpsa.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def limited_higher_rate_in_kbs(self):
        """Gets the limited_higher_rate_in_kbs of this RemoteVpsa.  # noqa: E501


        :return: The limited_higher_rate_in_kbs of this RemoteVpsa.  # noqa: E501
        :rtype: int
        """
        return self._limited_higher_rate_in_kbs

    @limited_higher_rate_in_kbs.setter
    def limited_higher_rate_in_kbs(self, limited_higher_rate_in_kbs):
        """Sets the limited_higher_rate_in_kbs of this RemoteVpsa.


        :param limited_higher_rate_in_kbs: The limited_higher_rate_in_kbs of this RemoteVpsa.  # noqa: E501
        :type: int
        """

        self._limited_higher_rate_in_kbs = limited_higher_rate_in_kbs

    @property
    def features(self):
        """Gets the features of this RemoteVpsa.  # noqa: E501


        :return: The features of this RemoteVpsa.  # noqa: E501
        :rtype: RemoteVpsaFeatures
        """
        return self._features

    @features.setter
    def features(self, features):
        """Sets the features of this RemoteVpsa.


        :param features: The features of this RemoteVpsa.  # noqa: E501
        :type: RemoteVpsaFeatures
        """

        self._features = features

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RemoteVpsa, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoteVpsa):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RemoteVpsa):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse200268ResponseUsages(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'rd_iops': 'float',
        'rd_bandwidth': 'float',
        'rd_iotime': 'float',
        'rd_max_time': 'int',
        'rd_queue_len': 'int',
        'wrt_iops': 'float',
        'wrt_bandwidth': 'float',
        'wrt_iotime': 'float',
        'wrt_max_time': 'int',
        'wrt_queue_len': 'int',
        'nonrw_iops': 'float',
        'nonrw_bandwidth': 'float',
        'nonrw_iotime': 'float',
        'nonrw_max_time': 'int',
        'nonrw_queue_len': 'int',
        'xcopy_iops': 'float',
        'xcopy_bandwidth': 'float',
        'xcopy_iotime': 'float',
        'xcopy_max_time': 'int',
        'xcopy_queue_len': 'int',
        'other_iops': 'float',
        'other_bandwidth': 'float',
        'other_iotime': 'float',
        'other_max_time': 'int',
        'other_queue_len': 'int',
        'creat_iops': 'float',
        'creat_bandwidth': 'float',
        'creat_iotime': 'float',
        'creat_max_time': 'int',
        'creat_queue_len': 'int',
        'delet_iops': 'float',
        'delet_bandwidth': 'float',
        'delet_iotime': 'float',
        'delet_max_time': 'int',
        'delet_queue_len': 'int',
        'renam_iops': 'float',
        'renam_bandwidth': 'float',
        'renam_iotime': 'float',
        'renam_max_time': 'int',
        'renam_queue_len': 'int',
        'flush_iops': 'float',
        'flush_bandwidth': 'float',
        'flush_iotime': 'float',
        'flush_max_time': 'int',
        'flush_queue_len': 'int',
        'lock_iops': 'float',
        'lock_bandwidth': 'float',
        'lock_iotime': 'float',
        'lock_max_time': 'int',
        'lock_queue_len': 'int',
        'ulock_iops': 'float',
        'ulock_bandwidth': 'float',
        'ulock_iotime': 'float',
        'ulock_max_time': 'int',
        'ulock_queue_len': 'int',
        'geta_iops': 'float',
        'geta_bandwidth': 'float',
        'geta_iotime': 'float',
        'geta_max_time': 'int',
        'geta_queue_len': 'int',
        'seta_iops': 'float',
        'seta_bandwidth': 'float',
        'seta_iotime': 'float',
        'seta_max_time': 'int',
        'seta_queue_len': 'int',
        'rddir_iops': 'float',
        'rddir_bandwidth': 'float',
        'rddir_iotime': 'float',
        'rddir_max_time': 'int',
        'rddir_queue_len': 'int',
        'time': 'str'
    }

    attribute_map = {
        'rd_iops': 'rd_iops',
        'rd_bandwidth': 'rd_bandwidth',
        'rd_iotime': 'rd_iotime',
        'rd_max_time': 'rd_max_time',
        'rd_queue_len': 'rd_queue_len',
        'wrt_iops': 'wrt_iops',
        'wrt_bandwidth': 'wrt_bandwidth',
        'wrt_iotime': 'wrt_iotime',
        'wrt_max_time': 'wrt_max_time',
        'wrt_queue_len': 'wrt_queue_len',
        'nonrw_iops': 'nonrw_iops',
        'nonrw_bandwidth': 'nonrw_bandwidth',
        'nonrw_iotime': 'nonrw_iotime',
        'nonrw_max_time': 'nonrw_max_time',
        'nonrw_queue_len': 'nonrw_queue_len',
        'xcopy_iops': 'xcopy_iops',
        'xcopy_bandwidth': 'xcopy_bandwidth',
        'xcopy_iotime': 'xcopy_iotime',
        'xcopy_max_time': 'xcopy_max_time',
        'xcopy_queue_len': 'xcopy_queue_len',
        'other_iops': 'other_iops',
        'other_bandwidth': 'other_bandwidth',
        'other_iotime': 'other_iotime',
        'other_max_time': 'other_max_time',
        'other_queue_len': 'other_queue_len',
        'creat_iops': 'creat_iops',
        'creat_bandwidth': 'creat_bandwidth',
        'creat_iotime': 'creat_iotime',
        'creat_max_time': 'creat_max_time',
        'creat_queue_len': 'creat_queue_len',
        'delet_iops': 'delet_iops',
        'delet_bandwidth': 'delet_bandwidth',
        'delet_iotime': 'delet_iotime',
        'delet_max_time': 'delet_max_time',
        'delet_queue_len': 'delet_queue_len',
        'renam_iops': 'renam_iops',
        'renam_bandwidth': 'renam_bandwidth',
        'renam_iotime': 'renam_iotime',
        'renam_max_time': 'renam_max_time',
        'renam_queue_len': 'renam_queue_len',
        'flush_iops': 'flush_iops',
        'flush_bandwidth': 'flush_bandwidth',
        'flush_iotime': 'flush_iotime',
        'flush_max_time': 'flush_max_time',
        'flush_queue_len': 'flush_queue_len',
        'lock_iops': 'lock_iops',
        'lock_bandwidth': 'lock_bandwidth',
        'lock_iotime': 'lock_iotime',
        'lock_max_time': 'lock_max_time',
        'lock_queue_len': 'lock_queue_len',
        'ulock_iops': 'ulock_iops',
        'ulock_bandwidth': 'ulock_bandwidth',
        'ulock_iotime': 'ulock_iotime',
        'ulock_max_time': 'ulock_max_time',
        'ulock_queue_len': 'ulock_queue_len',
        'geta_iops': 'geta_iops',
        'geta_bandwidth': 'geta_bandwidth',
        'geta_iotime': 'geta_iotime',
        'geta_max_time': 'geta_max_time',
        'geta_queue_len': 'geta_queue_len',
        'seta_iops': 'seta_iops',
        'seta_bandwidth': 'seta_bandwidth',
        'seta_iotime': 'seta_iotime',
        'seta_max_time': 'seta_max_time',
        'seta_queue_len': 'seta_queue_len',
        'rddir_iops': 'rddir_iops',
        'rddir_bandwidth': 'rddir_bandwidth',
        'rddir_iotime': 'rddir_iotime',
        'rddir_max_time': 'rddir_max_time',
        'rddir_queue_len': 'rddir_queue_len',
        'time': 'time'
    }

    def __init__(self, rd_iops=None, rd_bandwidth=None, rd_iotime=None, rd_max_time=None, rd_queue_len=None, wrt_iops=None, wrt_bandwidth=None, wrt_iotime=None, wrt_max_time=None, wrt_queue_len=None, nonrw_iops=None, nonrw_bandwidth=None, nonrw_iotime=None, nonrw_max_time=None, nonrw_queue_len=None, xcopy_iops=None, xcopy_bandwidth=None, xcopy_iotime=None, xcopy_max_time=None, xcopy_queue_len=None, other_iops=None, other_bandwidth=None, other_iotime=None, other_max_time=None, other_queue_len=None, creat_iops=None, creat_bandwidth=None, creat_iotime=None, creat_max_time=None, creat_queue_len=None, delet_iops=None, delet_bandwidth=None, delet_iotime=None, delet_max_time=None, delet_queue_len=None, renam_iops=None, renam_bandwidth=None, renam_iotime=None, renam_max_time=None, renam_queue_len=None, flush_iops=None, flush_bandwidth=None, flush_iotime=None, flush_max_time=None, flush_queue_len=None, lock_iops=None, lock_bandwidth=None, lock_iotime=None, lock_max_time=None, lock_queue_len=None, ulock_iops=None, ulock_bandwidth=None, ulock_iotime=None, ulock_max_time=None, ulock_queue_len=None, geta_iops=None, geta_bandwidth=None, geta_iotime=None, geta_max_time=None, geta_queue_len=None, seta_iops=None, seta_bandwidth=None, seta_iotime=None, seta_max_time=None, seta_queue_len=None, rddir_iops=None, rddir_bandwidth=None, rddir_iotime=None, rddir_max_time=None, rddir_queue_len=None, time=None, _configuration=None):  # noqa: E501
        """InlineResponse200268ResponseUsages - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._rd_iops = None
        self._rd_bandwidth = None
        self._rd_iotime = None
        self._rd_max_time = None
        self._rd_queue_len = None
        self._wrt_iops = None
        self._wrt_bandwidth = None
        self._wrt_iotime = None
        self._wrt_max_time = None
        self._wrt_queue_len = None
        self._nonrw_iops = None
        self._nonrw_bandwidth = None
        self._nonrw_iotime = None
        self._nonrw_max_time = None
        self._nonrw_queue_len = None
        self._xcopy_iops = None
        self._xcopy_bandwidth = None
        self._xcopy_iotime = None
        self._xcopy_max_time = None
        self._xcopy_queue_len = None
        self._other_iops = None
        self._other_bandwidth = None
        self._other_iotime = None
        self._other_max_time = None
        self._other_queue_len = None
        self._creat_iops = None
        self._creat_bandwidth = None
        self._creat_iotime = None
        self._creat_max_time = None
        self._creat_queue_len = None
        self._delet_iops = None
        self._delet_bandwidth = None
        self._delet_iotime = None
        self._delet_max_time = None
        self._delet_queue_len = None
        self._renam_iops = None
        self._renam_bandwidth = None
        self._renam_iotime = None
        self._renam_max_time = None
        self._renam_queue_len = None
        self._flush_iops = None
        self._flush_bandwidth = None
        self._flush_iotime = None
        self._flush_max_time = None
        self._flush_queue_len = None
        self._lock_iops = None
        self._lock_bandwidth = None
        self._lock_iotime = None
        self._lock_max_time = None
        self._lock_queue_len = None
        self._ulock_iops = None
        self._ulock_bandwidth = None
        self._ulock_iotime = None
        self._ulock_max_time = None
        self._ulock_queue_len = None
        self._geta_iops = None
        self._geta_bandwidth = None
        self._geta_iotime = None
        self._geta_max_time = None
        self._geta_queue_len = None
        self._seta_iops = None
        self._seta_bandwidth = None
        self._seta_iotime = None
        self._seta_max_time = None
        self._seta_queue_len = None
        self._rddir_iops = None
        self._rddir_bandwidth = None
        self._rddir_iotime = None
        self._rddir_max_time = None
        self._rddir_queue_len = None
        self._time = None
        self.discriminator = None

        if rd_iops is not None:
            self.rd_iops = rd_iops
        if rd_bandwidth is not None:
            self.rd_bandwidth = rd_bandwidth
        if rd_iotime is not None:
            self.rd_iotime = rd_iotime
        if rd_max_time is not None:
            self.rd_max_time = rd_max_time
        if rd_queue_len is not None:
            self.rd_queue_len = rd_queue_len
        if wrt_iops is not None:
            self.wrt_iops = wrt_iops
        if wrt_bandwidth is not None:
            self.wrt_bandwidth = wrt_bandwidth
        if wrt_iotime is not None:
            self.wrt_iotime = wrt_iotime
        if wrt_max_time is not None:
            self.wrt_max_time = wrt_max_time
        if wrt_queue_len is not None:
            self.wrt_queue_len = wrt_queue_len
        if nonrw_iops is not None:
            self.nonrw_iops = nonrw_iops
        if nonrw_bandwidth is not None:
            self.nonrw_bandwidth = nonrw_bandwidth
        if nonrw_iotime is not None:
            self.nonrw_iotime = nonrw_iotime
        if nonrw_max_time is not None:
            self.nonrw_max_time = nonrw_max_time
        if nonrw_queue_len is not None:
            self.nonrw_queue_len = nonrw_queue_len
        if xcopy_iops is not None:
            self.xcopy_iops = xcopy_iops
        if xcopy_bandwidth is not None:
            self.xcopy_bandwidth = xcopy_bandwidth
        if xcopy_iotime is not None:
            self.xcopy_iotime = xcopy_iotime
        if xcopy_max_time is not None:
            self.xcopy_max_time = xcopy_max_time
        if xcopy_queue_len is not None:
            self.xcopy_queue_len = xcopy_queue_len
        if other_iops is not None:
            self.other_iops = other_iops
        if other_bandwidth is not None:
            self.other_bandwidth = other_bandwidth
        if other_iotime is not None:
            self.other_iotime = other_iotime
        if other_max_time is not None:
            self.other_max_time = other_max_time
        if other_queue_len is not None:
            self.other_queue_len = other_queue_len
        if creat_iops is not None:
            self.creat_iops = creat_iops
        if creat_bandwidth is not None:
            self.creat_bandwidth = creat_bandwidth
        if creat_iotime is not None:
            self.creat_iotime = creat_iotime
        if creat_max_time is not None:
            self.creat_max_time = creat_max_time
        if creat_queue_len is not None:
            self.creat_queue_len = creat_queue_len
        if delet_iops is not None:
            self.delet_iops = delet_iops
        if delet_bandwidth is not None:
            self.delet_bandwidth = delet_bandwidth
        if delet_iotime is not None:
            self.delet_iotime = delet_iotime
        if delet_max_time is not None:
            self.delet_max_time = delet_max_time
        if delet_queue_len is not None:
            self.delet_queue_len = delet_queue_len
        if renam_iops is not None:
            self.renam_iops = renam_iops
        if renam_bandwidth is not None:
            self.renam_bandwidth = renam_bandwidth
        if renam_iotime is not None:
            self.renam_iotime = renam_iotime
        if renam_max_time is not None:
            self.renam_max_time = renam_max_time
        if renam_queue_len is not None:
            self.renam_queue_len = renam_queue_len
        if flush_iops is not None:
            self.flush_iops = flush_iops
        if flush_bandwidth is not None:
            self.flush_bandwidth = flush_bandwidth
        if flush_iotime is not None:
            self.flush_iotime = flush_iotime
        if flush_max_time is not None:
            self.flush_max_time = flush_max_time
        if flush_queue_len is not None:
            self.flush_queue_len = flush_queue_len
        if lock_iops is not None:
            self.lock_iops = lock_iops
        if lock_bandwidth is not None:
            self.lock_bandwidth = lock_bandwidth
        if lock_iotime is not None:
            self.lock_iotime = lock_iotime
        if lock_max_time is not None:
            self.lock_max_time = lock_max_time
        if lock_queue_len is not None:
            self.lock_queue_len = lock_queue_len
        if ulock_iops is not None:
            self.ulock_iops = ulock_iops
        if ulock_bandwidth is not None:
            self.ulock_bandwidth = ulock_bandwidth
        if ulock_iotime is not None:
            self.ulock_iotime = ulock_iotime
        if ulock_max_time is not None:
            self.ulock_max_time = ulock_max_time
        if ulock_queue_len is not None:
            self.ulock_queue_len = ulock_queue_len
        if geta_iops is not None:
            self.geta_iops = geta_iops
        if geta_bandwidth is not None:
            self.geta_bandwidth = geta_bandwidth
        if geta_iotime is not None:
            self.geta_iotime = geta_iotime
        if geta_max_time is not None:
            self.geta_max_time = geta_max_time
        if geta_queue_len is not None:
            self.geta_queue_len = geta_queue_len
        if seta_iops is not None:
            self.seta_iops = seta_iops
        if seta_bandwidth is not None:
            self.seta_bandwidth = seta_bandwidth
        if seta_iotime is not None:
            self.seta_iotime = seta_iotime
        if seta_max_time is not None:
            self.seta_max_time = seta_max_time
        if seta_queue_len is not None:
            self.seta_queue_len = seta_queue_len
        if rddir_iops is not None:
            self.rddir_iops = rddir_iops
        if rddir_bandwidth is not None:
            self.rddir_bandwidth = rddir_bandwidth
        if rddir_iotime is not None:
            self.rddir_iotime = rddir_iotime
        if rddir_max_time is not None:
            self.rddir_max_time = rddir_max_time
        if rddir_queue_len is not None:
            self.rddir_queue_len = rddir_queue_len
        if time is not None:
            self.time = time

    @property
    def rd_iops(self):
        """Gets the rd_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rd_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._rd_iops

    @rd_iops.setter
    def rd_iops(self, rd_iops):
        """Sets the rd_iops of this InlineResponse200268ResponseUsages.


        :param rd_iops: The rd_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._rd_iops = rd_iops

    @property
    def rd_bandwidth(self):
        """Gets the rd_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rd_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._rd_bandwidth

    @rd_bandwidth.setter
    def rd_bandwidth(self, rd_bandwidth):
        """Sets the rd_bandwidth of this InlineResponse200268ResponseUsages.


        :param rd_bandwidth: The rd_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._rd_bandwidth = rd_bandwidth

    @property
    def rd_iotime(self):
        """Gets the rd_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rd_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._rd_iotime

    @rd_iotime.setter
    def rd_iotime(self, rd_iotime):
        """Sets the rd_iotime of this InlineResponse200268ResponseUsages.


        :param rd_iotime: The rd_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._rd_iotime = rd_iotime

    @property
    def rd_max_time(self):
        """Gets the rd_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rd_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._rd_max_time

    @rd_max_time.setter
    def rd_max_time(self, rd_max_time):
        """Sets the rd_max_time of this InlineResponse200268ResponseUsages.


        :param rd_max_time: The rd_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._rd_max_time = rd_max_time

    @property
    def rd_queue_len(self):
        """Gets the rd_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rd_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._rd_queue_len

    @rd_queue_len.setter
    def rd_queue_len(self, rd_queue_len):
        """Sets the rd_queue_len of this InlineResponse200268ResponseUsages.


        :param rd_queue_len: The rd_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._rd_queue_len = rd_queue_len

    @property
    def wrt_iops(self):
        """Gets the wrt_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The wrt_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._wrt_iops

    @wrt_iops.setter
    def wrt_iops(self, wrt_iops):
        """Sets the wrt_iops of this InlineResponse200268ResponseUsages.


        :param wrt_iops: The wrt_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._wrt_iops = wrt_iops

    @property
    def wrt_bandwidth(self):
        """Gets the wrt_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The wrt_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._wrt_bandwidth

    @wrt_bandwidth.setter
    def wrt_bandwidth(self, wrt_bandwidth):
        """Sets the wrt_bandwidth of this InlineResponse200268ResponseUsages.


        :param wrt_bandwidth: The wrt_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._wrt_bandwidth = wrt_bandwidth

    @property
    def wrt_iotime(self):
        """Gets the wrt_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The wrt_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._wrt_iotime

    @wrt_iotime.setter
    def wrt_iotime(self, wrt_iotime):
        """Sets the wrt_iotime of this InlineResponse200268ResponseUsages.


        :param wrt_iotime: The wrt_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._wrt_iotime = wrt_iotime

    @property
    def wrt_max_time(self):
        """Gets the wrt_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The wrt_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._wrt_max_time

    @wrt_max_time.setter
    def wrt_max_time(self, wrt_max_time):
        """Sets the wrt_max_time of this InlineResponse200268ResponseUsages.


        :param wrt_max_time: The wrt_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._wrt_max_time = wrt_max_time

    @property
    def wrt_queue_len(self):
        """Gets the wrt_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The wrt_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._wrt_queue_len

    @wrt_queue_len.setter
    def wrt_queue_len(self, wrt_queue_len):
        """Sets the wrt_queue_len of this InlineResponse200268ResponseUsages.


        :param wrt_queue_len: The wrt_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._wrt_queue_len = wrt_queue_len

    @property
    def nonrw_iops(self):
        """Gets the nonrw_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The nonrw_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._nonrw_iops

    @nonrw_iops.setter
    def nonrw_iops(self, nonrw_iops):
        """Sets the nonrw_iops of this InlineResponse200268ResponseUsages.


        :param nonrw_iops: The nonrw_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._nonrw_iops = nonrw_iops

    @property
    def nonrw_bandwidth(self):
        """Gets the nonrw_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The nonrw_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._nonrw_bandwidth

    @nonrw_bandwidth.setter
    def nonrw_bandwidth(self, nonrw_bandwidth):
        """Sets the nonrw_bandwidth of this InlineResponse200268ResponseUsages.


        :param nonrw_bandwidth: The nonrw_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._nonrw_bandwidth = nonrw_bandwidth

    @property
    def nonrw_iotime(self):
        """Gets the nonrw_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The nonrw_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._nonrw_iotime

    @nonrw_iotime.setter
    def nonrw_iotime(self, nonrw_iotime):
        """Sets the nonrw_iotime of this InlineResponse200268ResponseUsages.


        :param nonrw_iotime: The nonrw_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._nonrw_iotime = nonrw_iotime

    @property
    def nonrw_max_time(self):
        """Gets the nonrw_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The nonrw_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._nonrw_max_time

    @nonrw_max_time.setter
    def nonrw_max_time(self, nonrw_max_time):
        """Sets the nonrw_max_time of this InlineResponse200268ResponseUsages.


        :param nonrw_max_time: The nonrw_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._nonrw_max_time = nonrw_max_time

    @property
    def nonrw_queue_len(self):
        """Gets the nonrw_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The nonrw_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._nonrw_queue_len

    @nonrw_queue_len.setter
    def nonrw_queue_len(self, nonrw_queue_len):
        """Sets the nonrw_queue_len of this InlineResponse200268ResponseUsages.


        :param nonrw_queue_len: The nonrw_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._nonrw_queue_len = nonrw_queue_len

    @property
    def xcopy_iops(self):
        """Gets the xcopy_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The xcopy_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._xcopy_iops

    @xcopy_iops.setter
    def xcopy_iops(self, xcopy_iops):
        """Sets the xcopy_iops of this InlineResponse200268ResponseUsages.


        :param xcopy_iops: The xcopy_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._xcopy_iops = xcopy_iops

    @property
    def xcopy_bandwidth(self):
        """Gets the xcopy_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The xcopy_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._xcopy_bandwidth

    @xcopy_bandwidth.setter
    def xcopy_bandwidth(self, xcopy_bandwidth):
        """Sets the xcopy_bandwidth of this InlineResponse200268ResponseUsages.


        :param xcopy_bandwidth: The xcopy_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._xcopy_bandwidth = xcopy_bandwidth

    @property
    def xcopy_iotime(self):
        """Gets the xcopy_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The xcopy_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._xcopy_iotime

    @xcopy_iotime.setter
    def xcopy_iotime(self, xcopy_iotime):
        """Sets the xcopy_iotime of this InlineResponse200268ResponseUsages.


        :param xcopy_iotime: The xcopy_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._xcopy_iotime = xcopy_iotime

    @property
    def xcopy_max_time(self):
        """Gets the xcopy_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The xcopy_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._xcopy_max_time

    @xcopy_max_time.setter
    def xcopy_max_time(self, xcopy_max_time):
        """Sets the xcopy_max_time of this InlineResponse200268ResponseUsages.


        :param xcopy_max_time: The xcopy_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._xcopy_max_time = xcopy_max_time

    @property
    def xcopy_queue_len(self):
        """Gets the xcopy_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The xcopy_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._xcopy_queue_len

    @xcopy_queue_len.setter
    def xcopy_queue_len(self, xcopy_queue_len):
        """Sets the xcopy_queue_len of this InlineResponse200268ResponseUsages.


        :param xcopy_queue_len: The xcopy_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._xcopy_queue_len = xcopy_queue_len

    @property
    def other_iops(self):
        """Gets the other_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The other_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._other_iops

    @other_iops.setter
    def other_iops(self, other_iops):
        """Sets the other_iops of this InlineResponse200268ResponseUsages.


        :param other_iops: The other_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._other_iops = other_iops

    @property
    def other_bandwidth(self):
        """Gets the other_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The other_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._other_bandwidth

    @other_bandwidth.setter
    def other_bandwidth(self, other_bandwidth):
        """Sets the other_bandwidth of this InlineResponse200268ResponseUsages.


        :param other_bandwidth: The other_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._other_bandwidth = other_bandwidth

    @property
    def other_iotime(self):
        """Gets the other_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The other_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._other_iotime

    @other_iotime.setter
    def other_iotime(self, other_iotime):
        """Sets the other_iotime of this InlineResponse200268ResponseUsages.


        :param other_iotime: The other_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._other_iotime = other_iotime

    @property
    def other_max_time(self):
        """Gets the other_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The other_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._other_max_time

    @other_max_time.setter
    def other_max_time(self, other_max_time):
        """Sets the other_max_time of this InlineResponse200268ResponseUsages.


        :param other_max_time: The other_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._other_max_time = other_max_time

    @property
    def other_queue_len(self):
        """Gets the other_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The other_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._other_queue_len

    @other_queue_len.setter
    def other_queue_len(self, other_queue_len):
        """Sets the other_queue_len of this InlineResponse200268ResponseUsages.


        :param other_queue_len: The other_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._other_queue_len = other_queue_len

    @property
    def creat_iops(self):
        """Gets the creat_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The creat_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._creat_iops

    @creat_iops.setter
    def creat_iops(self, creat_iops):
        """Sets the creat_iops of this InlineResponse200268ResponseUsages.


        :param creat_iops: The creat_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._creat_iops = creat_iops

    @property
    def creat_bandwidth(self):
        """Gets the creat_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The creat_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._creat_bandwidth

    @creat_bandwidth.setter
    def creat_bandwidth(self, creat_bandwidth):
        """Sets the creat_bandwidth of this InlineResponse200268ResponseUsages.


        :param creat_bandwidth: The creat_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._creat_bandwidth = creat_bandwidth

    @property
    def creat_iotime(self):
        """Gets the creat_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The creat_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._creat_iotime

    @creat_iotime.setter
    def creat_iotime(self, creat_iotime):
        """Sets the creat_iotime of this InlineResponse200268ResponseUsages.


        :param creat_iotime: The creat_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._creat_iotime = creat_iotime

    @property
    def creat_max_time(self):
        """Gets the creat_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The creat_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._creat_max_time

    @creat_max_time.setter
    def creat_max_time(self, creat_max_time):
        """Sets the creat_max_time of this InlineResponse200268ResponseUsages.


        :param creat_max_time: The creat_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._creat_max_time = creat_max_time

    @property
    def creat_queue_len(self):
        """Gets the creat_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The creat_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._creat_queue_len

    @creat_queue_len.setter
    def creat_queue_len(self, creat_queue_len):
        """Sets the creat_queue_len of this InlineResponse200268ResponseUsages.


        :param creat_queue_len: The creat_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._creat_queue_len = creat_queue_len

    @property
    def delet_iops(self):
        """Gets the delet_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The delet_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._delet_iops

    @delet_iops.setter
    def delet_iops(self, delet_iops):
        """Sets the delet_iops of this InlineResponse200268ResponseUsages.


        :param delet_iops: The delet_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._delet_iops = delet_iops

    @property
    def delet_bandwidth(self):
        """Gets the delet_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The delet_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._delet_bandwidth

    @delet_bandwidth.setter
    def delet_bandwidth(self, delet_bandwidth):
        """Sets the delet_bandwidth of this InlineResponse200268ResponseUsages.


        :param delet_bandwidth: The delet_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._delet_bandwidth = delet_bandwidth

    @property
    def delet_iotime(self):
        """Gets the delet_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The delet_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._delet_iotime

    @delet_iotime.setter
    def delet_iotime(self, delet_iotime):
        """Sets the delet_iotime of this InlineResponse200268ResponseUsages.


        :param delet_iotime: The delet_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._delet_iotime = delet_iotime

    @property
    def delet_max_time(self):
        """Gets the delet_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The delet_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._delet_max_time

    @delet_max_time.setter
    def delet_max_time(self, delet_max_time):
        """Sets the delet_max_time of this InlineResponse200268ResponseUsages.


        :param delet_max_time: The delet_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._delet_max_time = delet_max_time

    @property
    def delet_queue_len(self):
        """Gets the delet_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The delet_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._delet_queue_len

    @delet_queue_len.setter
    def delet_queue_len(self, delet_queue_len):
        """Sets the delet_queue_len of this InlineResponse200268ResponseUsages.


        :param delet_queue_len: The delet_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._delet_queue_len = delet_queue_len

    @property
    def renam_iops(self):
        """Gets the renam_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The renam_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._renam_iops

    @renam_iops.setter
    def renam_iops(self, renam_iops):
        """Sets the renam_iops of this InlineResponse200268ResponseUsages.


        :param renam_iops: The renam_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._renam_iops = renam_iops

    @property
    def renam_bandwidth(self):
        """Gets the renam_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The renam_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._renam_bandwidth

    @renam_bandwidth.setter
    def renam_bandwidth(self, renam_bandwidth):
        """Sets the renam_bandwidth of this InlineResponse200268ResponseUsages.


        :param renam_bandwidth: The renam_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._renam_bandwidth = renam_bandwidth

    @property
    def renam_iotime(self):
        """Gets the renam_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The renam_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._renam_iotime

    @renam_iotime.setter
    def renam_iotime(self, renam_iotime):
        """Sets the renam_iotime of this InlineResponse200268ResponseUsages.


        :param renam_iotime: The renam_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._renam_iotime = renam_iotime

    @property
    def renam_max_time(self):
        """Gets the renam_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The renam_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._renam_max_time

    @renam_max_time.setter
    def renam_max_time(self, renam_max_time):
        """Sets the renam_max_time of this InlineResponse200268ResponseUsages.


        :param renam_max_time: The renam_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._renam_max_time = renam_max_time

    @property
    def renam_queue_len(self):
        """Gets the renam_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The renam_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._renam_queue_len

    @renam_queue_len.setter
    def renam_queue_len(self, renam_queue_len):
        """Sets the renam_queue_len of this InlineResponse200268ResponseUsages.


        :param renam_queue_len: The renam_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._renam_queue_len = renam_queue_len

    @property
    def flush_iops(self):
        """Gets the flush_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The flush_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._flush_iops

    @flush_iops.setter
    def flush_iops(self, flush_iops):
        """Sets the flush_iops of this InlineResponse200268ResponseUsages.


        :param flush_iops: The flush_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._flush_iops = flush_iops

    @property
    def flush_bandwidth(self):
        """Gets the flush_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The flush_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._flush_bandwidth

    @flush_bandwidth.setter
    def flush_bandwidth(self, flush_bandwidth):
        """Sets the flush_bandwidth of this InlineResponse200268ResponseUsages.


        :param flush_bandwidth: The flush_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._flush_bandwidth = flush_bandwidth

    @property
    def flush_iotime(self):
        """Gets the flush_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The flush_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._flush_iotime

    @flush_iotime.setter
    def flush_iotime(self, flush_iotime):
        """Sets the flush_iotime of this InlineResponse200268ResponseUsages.


        :param flush_iotime: The flush_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._flush_iotime = flush_iotime

    @property
    def flush_max_time(self):
        """Gets the flush_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The flush_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._flush_max_time

    @flush_max_time.setter
    def flush_max_time(self, flush_max_time):
        """Sets the flush_max_time of this InlineResponse200268ResponseUsages.


        :param flush_max_time: The flush_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._flush_max_time = flush_max_time

    @property
    def flush_queue_len(self):
        """Gets the flush_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The flush_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._flush_queue_len

    @flush_queue_len.setter
    def flush_queue_len(self, flush_queue_len):
        """Sets the flush_queue_len of this InlineResponse200268ResponseUsages.


        :param flush_queue_len: The flush_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._flush_queue_len = flush_queue_len

    @property
    def lock_iops(self):
        """Gets the lock_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The lock_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._lock_iops

    @lock_iops.setter
    def lock_iops(self, lock_iops):
        """Sets the lock_iops of this InlineResponse200268ResponseUsages.


        :param lock_iops: The lock_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._lock_iops = lock_iops

    @property
    def lock_bandwidth(self):
        """Gets the lock_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The lock_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._lock_bandwidth

    @lock_bandwidth.setter
    def lock_bandwidth(self, lock_bandwidth):
        """Sets the lock_bandwidth of this InlineResponse200268ResponseUsages.


        :param lock_bandwidth: The lock_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._lock_bandwidth = lock_bandwidth

    @property
    def lock_iotime(self):
        """Gets the lock_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The lock_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._lock_iotime

    @lock_iotime.setter
    def lock_iotime(self, lock_iotime):
        """Sets the lock_iotime of this InlineResponse200268ResponseUsages.


        :param lock_iotime: The lock_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._lock_iotime = lock_iotime

    @property
    def lock_max_time(self):
        """Gets the lock_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The lock_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._lock_max_time

    @lock_max_time.setter
    def lock_max_time(self, lock_max_time):
        """Sets the lock_max_time of this InlineResponse200268ResponseUsages.


        :param lock_max_time: The lock_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._lock_max_time = lock_max_time

    @property
    def lock_queue_len(self):
        """Gets the lock_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The lock_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._lock_queue_len

    @lock_queue_len.setter
    def lock_queue_len(self, lock_queue_len):
        """Sets the lock_queue_len of this InlineResponse200268ResponseUsages.


        :param lock_queue_len: The lock_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._lock_queue_len = lock_queue_len

    @property
    def ulock_iops(self):
        """Gets the ulock_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The ulock_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._ulock_iops

    @ulock_iops.setter
    def ulock_iops(self, ulock_iops):
        """Sets the ulock_iops of this InlineResponse200268ResponseUsages.


        :param ulock_iops: The ulock_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._ulock_iops = ulock_iops

    @property
    def ulock_bandwidth(self):
        """Gets the ulock_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The ulock_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._ulock_bandwidth

    @ulock_bandwidth.setter
    def ulock_bandwidth(self, ulock_bandwidth):
        """Sets the ulock_bandwidth of this InlineResponse200268ResponseUsages.


        :param ulock_bandwidth: The ulock_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._ulock_bandwidth = ulock_bandwidth

    @property
    def ulock_iotime(self):
        """Gets the ulock_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The ulock_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._ulock_iotime

    @ulock_iotime.setter
    def ulock_iotime(self, ulock_iotime):
        """Sets the ulock_iotime of this InlineResponse200268ResponseUsages.


        :param ulock_iotime: The ulock_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._ulock_iotime = ulock_iotime

    @property
    def ulock_max_time(self):
        """Gets the ulock_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The ulock_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._ulock_max_time

    @ulock_max_time.setter
    def ulock_max_time(self, ulock_max_time):
        """Sets the ulock_max_time of this InlineResponse200268ResponseUsages.


        :param ulock_max_time: The ulock_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._ulock_max_time = ulock_max_time

    @property
    def ulock_queue_len(self):
        """Gets the ulock_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The ulock_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._ulock_queue_len

    @ulock_queue_len.setter
    def ulock_queue_len(self, ulock_queue_len):
        """Sets the ulock_queue_len of this InlineResponse200268ResponseUsages.


        :param ulock_queue_len: The ulock_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._ulock_queue_len = ulock_queue_len

    @property
    def geta_iops(self):
        """Gets the geta_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The geta_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._geta_iops

    @geta_iops.setter
    def geta_iops(self, geta_iops):
        """Sets the geta_iops of this InlineResponse200268ResponseUsages.


        :param geta_iops: The geta_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._geta_iops = geta_iops

    @property
    def geta_bandwidth(self):
        """Gets the geta_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The geta_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._geta_bandwidth

    @geta_bandwidth.setter
    def geta_bandwidth(self, geta_bandwidth):
        """Sets the geta_bandwidth of this InlineResponse200268ResponseUsages.


        :param geta_bandwidth: The geta_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._geta_bandwidth = geta_bandwidth

    @property
    def geta_iotime(self):
        """Gets the geta_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The geta_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._geta_iotime

    @geta_iotime.setter
    def geta_iotime(self, geta_iotime):
        """Sets the geta_iotime of this InlineResponse200268ResponseUsages.


        :param geta_iotime: The geta_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._geta_iotime = geta_iotime

    @property
    def geta_max_time(self):
        """Gets the geta_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The geta_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._geta_max_time

    @geta_max_time.setter
    def geta_max_time(self, geta_max_time):
        """Sets the geta_max_time of this InlineResponse200268ResponseUsages.


        :param geta_max_time: The geta_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._geta_max_time = geta_max_time

    @property
    def geta_queue_len(self):
        """Gets the geta_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The geta_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._geta_queue_len

    @geta_queue_len.setter
    def geta_queue_len(self, geta_queue_len):
        """Sets the geta_queue_len of this InlineResponse200268ResponseUsages.


        :param geta_queue_len: The geta_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._geta_queue_len = geta_queue_len

    @property
    def seta_iops(self):
        """Gets the seta_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The seta_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._seta_iops

    @seta_iops.setter
    def seta_iops(self, seta_iops):
        """Sets the seta_iops of this InlineResponse200268ResponseUsages.


        :param seta_iops: The seta_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._seta_iops = seta_iops

    @property
    def seta_bandwidth(self):
        """Gets the seta_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The seta_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._seta_bandwidth

    @seta_bandwidth.setter
    def seta_bandwidth(self, seta_bandwidth):
        """Sets the seta_bandwidth of this InlineResponse200268ResponseUsages.


        :param seta_bandwidth: The seta_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._seta_bandwidth = seta_bandwidth

    @property
    def seta_iotime(self):
        """Gets the seta_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The seta_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._seta_iotime

    @seta_iotime.setter
    def seta_iotime(self, seta_iotime):
        """Sets the seta_iotime of this InlineResponse200268ResponseUsages.


        :param seta_iotime: The seta_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._seta_iotime = seta_iotime

    @property
    def seta_max_time(self):
        """Gets the seta_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The seta_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._seta_max_time

    @seta_max_time.setter
    def seta_max_time(self, seta_max_time):
        """Sets the seta_max_time of this InlineResponse200268ResponseUsages.


        :param seta_max_time: The seta_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._seta_max_time = seta_max_time

    @property
    def seta_queue_len(self):
        """Gets the seta_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The seta_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._seta_queue_len

    @seta_queue_len.setter
    def seta_queue_len(self, seta_queue_len):
        """Sets the seta_queue_len of this InlineResponse200268ResponseUsages.


        :param seta_queue_len: The seta_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._seta_queue_len = seta_queue_len

    @property
    def rddir_iops(self):
        """Gets the rddir_iops of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rddir_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._rddir_iops

    @rddir_iops.setter
    def rddir_iops(self, rddir_iops):
        """Sets the rddir_iops of this InlineResponse200268ResponseUsages.


        :param rddir_iops: The rddir_iops of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._rddir_iops = rddir_iops

    @property
    def rddir_bandwidth(self):
        """Gets the rddir_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rddir_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._rddir_bandwidth

    @rddir_bandwidth.setter
    def rddir_bandwidth(self, rddir_bandwidth):
        """Sets the rddir_bandwidth of this InlineResponse200268ResponseUsages.


        :param rddir_bandwidth: The rddir_bandwidth of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._rddir_bandwidth = rddir_bandwidth

    @property
    def rddir_iotime(self):
        """Gets the rddir_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rddir_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: float
        """
        return self._rddir_iotime

    @rddir_iotime.setter
    def rddir_iotime(self, rddir_iotime):
        """Sets the rddir_iotime of this InlineResponse200268ResponseUsages.


        :param rddir_iotime: The rddir_iotime of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: float
        """

        self._rddir_iotime = rddir_iotime

    @property
    def rddir_max_time(self):
        """Gets the rddir_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rddir_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._rddir_max_time

    @rddir_max_time.setter
    def rddir_max_time(self, rddir_max_time):
        """Sets the rddir_max_time of this InlineResponse200268ResponseUsages.


        :param rddir_max_time: The rddir_max_time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._rddir_max_time = rddir_max_time

    @property
    def rddir_queue_len(self):
        """Gets the rddir_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501


        :return: The rddir_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: int
        """
        return self._rddir_queue_len

    @rddir_queue_len.setter
    def rddir_queue_len(self, rddir_queue_len):
        """Sets the rddir_queue_len of this InlineResponse200268ResponseUsages.


        :param rddir_queue_len: The rddir_queue_len of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: int
        """

        self._rddir_queue_len = rddir_queue_len

    @property
    def time(self):
        """Gets the time of this InlineResponse200268ResponseUsages.  # noqa: E501

        the time to which the stats relate to  # noqa: E501

        :return: The time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this InlineResponse200268ResponseUsages.

        the time to which the stats relate to  # noqa: E501

        :param time: The time of this InlineResponse200268ResponseUsages.  # noqa: E501
        :type: str
        """

        self._time = time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200268ResponseUsages, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200268ResponseUsages):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200268ResponseUsages):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class RemoteVpsaFeatures(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'wan_optimization': 'str',
        'manual_snaps': 'str',
        'reconnect_policies': 'str',
        'archival_pool': 'str',
        'remote_clone': 'str',
        'inherit_src_id': 'str',
        'four_mb_chunk_size': 'str',
        'extended_xcopy': 'str',
        'afa': 'str'
    }

    attribute_map = {
        'wan_optimization': 'wan_optimization',
        'manual_snaps': 'manual_snaps',
        'reconnect_policies': 'reconnect_policies',
        'archival_pool': 'archival_pool',
        'remote_clone': 'remote_clone',
        'inherit_src_id': 'inherit_src_id',
        'four_mb_chunk_size': 'four_mb_chunk_size',
        'extended_xcopy': 'extended_xcopy',
        'afa': 'afa'
    }

    def __init__(self, wan_optimization=None, manual_snaps=None, reconnect_policies=None, archival_pool=None, remote_clone=None, inherit_src_id=None, four_mb_chunk_size=None, extended_xcopy=None, afa=None, _configuration=None):  # noqa: E501
        """RemoteVpsaFeatures - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._wan_optimization = None
        self._manual_snaps = None
        self._reconnect_policies = None
        self._archival_pool = None
        self._remote_clone = None
        self._inherit_src_id = None
        self._four_mb_chunk_size = None
        self._extended_xcopy = None
        self._afa = None
        self.discriminator = None

        if wan_optimization is not None:
            self.wan_optimization = wan_optimization
        if manual_snaps is not None:
            self.manual_snaps = manual_snaps
        if reconnect_policies is not None:
            self.reconnect_policies = reconnect_policies
        if archival_pool is not None:
            self.archival_pool = archival_pool
        if remote_clone is not None:
            self.remote_clone = remote_clone
        if inherit_src_id is not None:
            self.inherit_src_id = inherit_src_id
        if four_mb_chunk_size is not None:
            self.four_mb_chunk_size = four_mb_chunk_size
        if extended_xcopy is not None:
            self.extended_xcopy = extended_xcopy
        if afa is not None:
            self.afa = afa

    @property
    def wan_optimization(self):
        """Gets the wan_optimization of this RemoteVpsaFeatures.  # noqa: E501


        :return: The wan_optimization of this RemoteVpsaFeatures.  # noqa: E501
        :rtype: str
        """
        return self._wan_optimization

    @wan_optimization.setter
    def wan_optimization(self, wan_optimization):
        """Sets the wan_optimization of this RemoteVpsaFeatures.


        :param wan_optimization: The wan_optimization of this RemoteVpsaFeatures.  # noqa: E501
        :type: str
        """

        self._wan_optimization = wan_optimization

    @property
    def manual_snaps(self):
        """Gets the manual_snaps of this RemoteVpsaFeatures.  # noqa: E501


        :return: The manual_snaps of this RemoteVpsaFeatures.  # noqa: E501
        :rtype: str
        """
        return self._manual_snaps

    @manual_snaps.setter
    def manual_snaps(self, manual_snaps):
        """Sets the manual_snaps of this RemoteVpsaFeatures.


        :param manual_snaps: The manual_snaps of this RemoteVpsaFeatures.  # noqa: E501
        :type: str
        """

        self._manual_snaps = manual_snaps

    @property
    def reconnect_policies(self):
        """Gets the reconnect_policies of this RemoteVpsaFeatures.  # noqa: E501


        :return: The reconnect_policies of this RemoteVpsaFeatures.  # noqa: E501
        :rtype: str
        """
        return self._reconnect_policies

    @reconnect_policies.setter
    def reconnect_policies(self, reconnect_policies):
        """Sets the reconnect_policies of this RemoteVpsaFeatures.


        :param reconnect_policies: The reconnect_policies of this RemoteVpsaFeatures.  # noqa: E501
        :type: str
        """

        self._reconnect_policies = reconnect_policies

    @property
    def archival_pool(self):
        """Gets the archival_pool of this RemoteVpsaFeatures.  # noqa: E501


        :return: The archival_pool of this RemoteVpsaFeatures.  # noqa: E501
        :rtype: str
        """
        return self._archival_pool

    @archival_pool.setter
    def archival_pool(self, archival_pool):
        """Sets the archival_pool of this RemoteVpsaFeatures.


        :param archival_pool: The archival_pool of this RemoteVpsaFeatures.  # noqa: E501
        :type: str
        """

        self._archival_pool = archival_pool

    @property
    def remote_clone(self):
        """Gets the remote_clone of this RemoteVpsaFeatures.  # noqa: E501


        :return: The remote_clone of this RemoteVpsaFeatures.  # noqa: E501
        :rtype: str
        """
        return self._remote_clone

    @remote_clone.setter
    def remote_clone(self, remote_clone):
        """Sets the remote_clone of this RemoteVpsaFeatures.


        :param remote_clone: The remote_clone of this RemoteVpsaFeatures.  # noqa: E501
        :type: str
        """

        self._remote_clone = remote_clone

    @property
    def inherit_src_id(self):
        """Gets the inherit_src_id of this RemoteVpsaFeatures.  # noqa: E501


        :return: The inherit_src_id of this RemoteVpsaFeatures.  # noqa: E501
        :rtype: str
        """
        return self._inherit_src_id

    @inherit_src_id.setter
    def inherit_src_id(self, inherit_src_id):
        """Sets the inherit_src_id of this RemoteVpsaFeatures.


        :param inherit_src_id: The inherit_src_id of this RemoteVpsaFeatures.  # noqa: E501
        :type: str
        """

        self._inherit_src_id = inherit_src_id

    @property
    def four_mb_chunk_size(self):
        """Gets the four_mb_chunk_size of this RemoteVpsaFeatures.  # noqa: E501


        :return: The four_mb_chunk_size of this RemoteVpsaFeatures.  # noqa: E501
        :rtype: str
        """
        return self._four_mb_chunk_size

    @four_mb_chunk_size.setter
    def four_mb_chunk_size(self, four_mb_chunk_size):
        """Sets the four_mb_chunk_size of this RemoteVpsaFeatures.


        :param four_mb_chunk_size: The four_mb_chunk_size of this RemoteVpsaFeatures.  # noqa: E501
        :type: str
        """

        self._four_mb_chunk_size = four_mb_chunk_size

    @property
    def extended_xcopy(self):
        """Gets the extended_xcopy of this RemoteVpsaFeatures.  # noqa: E501


        :return: The extended_xcopy of this RemoteVpsaFeatures.  # noqa: E501
        :rtype: str
        """
        return self._extended_xcopy

    @extended_xcopy.setter
    def extended_xcopy(self, extended_xcopy):
        """Sets the extended_xcopy of this RemoteVpsaFeatures.


        :param extended_xcopy: The extended_xcopy of this RemoteVpsaFeatures.  # noqa: E501
        :type: str
        """

        self._extended_xcopy = extended_xcopy

    @property
    def afa(self):
        """Gets the afa of this RemoteVpsaFeatures.  # noqa: E501


        :return: The afa of this RemoteVpsaFeatures.  # noqa: E501
        :rtype: str
        """
        return self._afa

    @afa.setter
    def afa(self, afa):
        """Sets the afa of this RemoteVpsaFeatures.


        :param afa: The afa of this RemoteVpsaFeatures.  # noqa: E501
        :type: str
        """

        self._afa = afa

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RemoteVpsaFeatures, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoteVpsaFeatures):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RemoteVpsaFeatures):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class UpdateProtection(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alertmode': 'int',
        'emergencymode': 'int',
        'capacityhistory': 'int',
        'autoexpand': 'str',
        'maxcapacity': 'str',
        'autoexpandby': 'str'
    }

    attribute_map = {
        'alertmode': 'alertmode',
        'emergencymode': 'emergencymode',
        'capacityhistory': 'capacityhistory',
        'autoexpand': 'autoexpand',
        'maxcapacity': 'maxcapacity',
        'autoexpandby': 'autoexpandby'
    }

    def __init__(self, alertmode=None, emergencymode=None, capacityhistory=None, autoexpand=None, maxcapacity=None, autoexpandby=None, _configuration=None):  # noqa: E501
        """UpdateProtection - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._alertmode = None
        self._emergencymode = None
        self._capacityhistory = None
        self._autoexpand = None
        self._maxcapacity = None
        self._autoexpandby = None
        self.discriminator = None

        if alertmode is not None:
            self.alertmode = alertmode
        if emergencymode is not None:
            self.emergencymode = emergencymode
        if capacityhistory is not None:
            self.capacityhistory = capacityhistory
        if autoexpand is not None:
            self.autoexpand = autoexpand
        if maxcapacity is not None:
            self.maxcapacity = maxcapacity
        if autoexpandby is not None:
            self.autoexpandby = autoexpandby

    @property
    def alertmode(self):
        """Gets the alertmode of this UpdateProtection.  # noqa: E501

        Alert me when it is estimated that the Volume will be at full capacity in X minutes.  # noqa: E501

        :return: The alertmode of this UpdateProtection.  # noqa: E501
        :rtype: int
        """
        return self._alertmode

    @alertmode.setter
    def alertmode(self, alertmode):
        """Sets the alertmode of this UpdateProtection.

        Alert me when it is estimated that the Volume will be at full capacity in X minutes.  # noqa: E501

        :param alertmode: The alertmode of this UpdateProtection.  # noqa: E501
        :type: int
        """

        self._alertmode = alertmode

    @property
    def emergencymode(self):
        """Gets the emergencymode of this UpdateProtection.  # noqa: E501

        When the Volume has less than this number of GB left, the volume will start deleting snapshots, starting with the oldest, and trigger auto expand.  # noqa: E501

        :return: The emergencymode of this UpdateProtection.  # noqa: E501
        :rtype: int
        """
        return self._emergencymode

    @emergencymode.setter
    def emergencymode(self, emergencymode):
        """Sets the emergencymode of this UpdateProtection.

        When the Volume has less than this number of GB left, the volume will start deleting snapshots, starting with the oldest, and trigger auto expand.  # noqa: E501

        :param emergencymode: The emergencymode of this UpdateProtection.  # noqa: E501
        :type: int
        """

        self._emergencymode = emergencymode

    @property
    def capacityhistory(self):
        """Gets the capacityhistory of this UpdateProtection.  # noqa: E501

        Window size in minutes which is used to calculate the rate of which free Volume capacity is consumed. This rate is used to calculate the estimated time until a Volume is full  # noqa: E501

        :return: The capacityhistory of this UpdateProtection.  # noqa: E501
        :rtype: int
        """
        return self._capacityhistory

    @capacityhistory.setter
    def capacityhistory(self, capacityhistory):
        """Sets the capacityhistory of this UpdateProtection.

        Window size in minutes which is used to calculate the rate of which free Volume capacity is consumed. This rate is used to calculate the estimated time until a Volume is full  # noqa: E501

        :param capacityhistory: The capacityhistory of this UpdateProtection.  # noqa: E501
        :type: int
        """

        self._capacityhistory = capacityhistory

    @property
    def autoexpand(self):
        """Gets the autoexpand of this UpdateProtection.  # noqa: E501

        Enable capacity auto expand  # noqa: E501

        :return: The autoexpand of this UpdateProtection.  # noqa: E501
        :rtype: str
        """
        return self._autoexpand

    @autoexpand.setter
    def autoexpand(self, autoexpand):
        """Sets the autoexpand of this UpdateProtection.

        Enable capacity auto expand  # noqa: E501

        :param autoexpand: The autoexpand of this UpdateProtection.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                autoexpand not in allowed_values):
            raise ValueError(
                "Invalid value for `autoexpand` ({0}), must be one of {1}"  # noqa: E501
                .format(autoexpand, allowed_values)
            )

        self._autoexpand = autoexpand

    @property
    def maxcapacity(self):
        """Gets the maxcapacity of this UpdateProtection.  # noqa: E501

        Max Capacity to expand in GB followed by the letter G.  # noqa: E501

        :return: The maxcapacity of this UpdateProtection.  # noqa: E501
        :rtype: str
        """
        return self._maxcapacity

    @maxcapacity.setter
    def maxcapacity(self, maxcapacity):
        """Sets the maxcapacity of this UpdateProtection.

        Max Capacity to expand in GB followed by the letter G.  # noqa: E501

        :param maxcapacity: The maxcapacity of this UpdateProtection.  # noqa: E501
        :type: str
        """

        self._maxcapacity = maxcapacity

    @property
    def autoexpandby(self):
        """Gets the autoexpandby of this UpdateProtection.  # noqa: E501

        Capacity to expand by in GB followed by the letter G.  # noqa: E501

        :return: The autoexpandby of this UpdateProtection.  # noqa: E501
        :rtype: str
        """
        return self._autoexpandby

    @autoexpandby.setter
    def autoexpandby(self, autoexpandby):
        """Sets the autoexpandby of this UpdateProtection.

        Capacity to expand by in GB followed by the letter G.  # noqa: E501

        :param autoexpandby: The autoexpandby of this UpdateProtection.  # noqa: E501
        :type: str
        """

        self._autoexpandby = autoexpandby

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateProtection, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateProtection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateProtection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse20029ResponseTarget(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'job_count': 'int',
        'state': 'str',
        'endpoint': 'str',
        'access': 'str',
        'secret': 'str',
        'region': 'str',
        'network': 'str',
        'type': 'str',
        'ext_name': 'str',
        'display_name': 'str',
        'created_at': 'str',
        'modified_at': 'str'
    }

    attribute_map = {
        'id': 'id',
        'job_count': 'job_count',
        'state': 'state',
        'endpoint': 'endpoint',
        'access': 'access',
        'secret': 'secret',
        'region': 'region',
        'network': 'network',
        'type': 'type',
        'ext_name': 'ext_name',
        'display_name': 'display_name',
        'created_at': 'created_at',
        'modified_at': 'modified_at'
    }

    def __init__(self, id=None, job_count=None, state=None, endpoint=None, access=None, secret=None, region=None, network=None, type=None, ext_name=None, display_name=None, created_at=None, modified_at=None, _configuration=None):  # noqa: E501
        """InlineResponse20029ResponseTarget - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._job_count = None
        self._state = None
        self._endpoint = None
        self._access = None
        self._secret = None
        self._region = None
        self._network = None
        self._type = None
        self._ext_name = None
        self._display_name = None
        self._created_at = None
        self._modified_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if job_count is not None:
            self.job_count = job_count
        if state is not None:
            self.state = state
        if endpoint is not None:
            self.endpoint = endpoint
        if access is not None:
            self.access = access
        if secret is not None:
            self.secret = secret
        if region is not None:
            self.region = region
        if network is not None:
            self.network = network
        if type is not None:
            self.type = type
        if ext_name is not None:
            self.ext_name = ext_name
        if display_name is not None:
            self.display_name = display_name
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at

    @property
    def id(self):
        """Gets the id of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The id of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20029ResponseTarget.


        :param id: The id of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def job_count(self):
        """Gets the job_count of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The job_count of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: int
        """
        return self._job_count

    @job_count.setter
    def job_count(self, job_count):
        """Sets the job_count of this InlineResponse20029ResponseTarget.


        :param job_count: The job_count of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: int
        """

        self._job_count = job_count

    @property
    def state(self):
        """Gets the state of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The state of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InlineResponse20029ResponseTarget.


        :param state: The state of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def endpoint(self):
        """Gets the endpoint of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The endpoint of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this InlineResponse20029ResponseTarget.


        :param endpoint: The endpoint of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._endpoint = endpoint

    @property
    def access(self):
        """Gets the access of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The access of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._access

    @access.setter
    def access(self, access):
        """Sets the access of this InlineResponse20029ResponseTarget.


        :param access: The access of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._access = access

    @property
    def secret(self):
        """Gets the secret of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The secret of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this InlineResponse20029ResponseTarget.


        :param secret: The secret of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._secret = secret

    @property
    def region(self):
        """Gets the region of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The region of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this InlineResponse20029ResponseTarget.


        :param region: The region of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._region = region

    @property
    def network(self):
        """Gets the network of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The network of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._network

    @network.setter
    def network(self, network):
        """Sets the network of this InlineResponse20029ResponseTarget.


        :param network: The network of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._network = network

    @property
    def type(self):
        """Gets the type of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The type of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InlineResponse20029ResponseTarget.


        :param type: The type of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def ext_name(self):
        """Gets the ext_name of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The ext_name of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._ext_name

    @ext_name.setter
    def ext_name(self, ext_name):
        """Sets the ext_name of this InlineResponse20029ResponseTarget.


        :param ext_name: The ext_name of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._ext_name = ext_name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The display_name of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20029ResponseTarget.


        :param display_name: The display_name of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The created_at of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20029ResponseTarget.


        :param created_at: The created_at of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20029ResponseTarget.  # noqa: E501


        :return: The modified_at of this InlineResponse20029ResponseTarget.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20029ResponseTarget.


        :param modified_at: The modified_at of this InlineResponse20029ResponseTarget.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20029ResponseTarget, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20029ResponseTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20029ResponseTarget):
            return True

        return self.to_dict() != other.to_dict()
